ln_beta

Function ln_beta 

pub fn ln_beta(a: f64, b: f64) -> f64
ln B(a, b), the logarithm of the beta function. For large arguments, the log gammas it’s made of are huge and nearly cancel, so it’s computed from their Stirling series instead, as R’s lbeta is.