suggest

Function suggest 

pub fn suggest(
    bytes: &[u8],
    format: DataFormat,
    file: &str,
    limits: &InputLimits,
) -> Result<String, String>
Suggest a declaration, and the read that uses it, for the data in bytes, read from file in format.