Module failure

Module failure 

Worlds that ended at a fault, when the failure mode is partial (docs/semantics.md, section 11).

Structs

Failure
The worlds that failed at one place, with one kind of fault.
Failures
The worlds that failed, grouped by where and how.