pub fn combine(
results: Vec<(Value, f64)>,
missing: f64,
budget: &mut Budget,
) -> OpResult<Value>Expand description
Gather the results of applying an operation to each outcome of some distributions into a distribution. Results that are themselves distributions are mixed in. The result is always a distribution, even when only one outcome is possible.