pub struct Numeric {
pub mean: Quantity,
pub sd: Quantity,
pub percent: bool,
/* private fields */
}Expand description
The summaries of a group of real numbers, or of continuous values.
Fields
mean: Quantitysd: Quantitypercent: boolEvery value was a probability (shown as percentages).
Implementations
Sourceimpl Numeric
impl Numeric
Sourcepub fn quantile(&self, q: f64) -> Option<Quantity>
pub fn quantile(&self, q: f64) -> Option<Quantity>
The q quantile, by the report convention: the median is the
midpoint of the middle values, the others select an outcome. q must
be in [0, 1].
Sourcepub fn quantile_value(&self, q: f64) -> Option<Value>
pub fn quantile_value(&self, q: f64) -> Option<Value>
The q quantile of point masses as a value, for printing integers
exactly.