merge

Function merge 

pub fn merge(worlds: Vec<World>, live: &SlotSet, enabled: bool) -> Vec<World>
If enabled, merge the worlds that agree on the live slots, adding up their weights, and keeping the order of first appearance. Dead slots don’t matter, cleared or not.