pub struct World {
pub slots: Vec<Value>,
pub constraints: Constraints,
pub inherited: Arc<BTreeSet<u64>>,
pub weight: Weight,
pub run: u32,
}Expand description
One possible state of the program: the variables of the current frame, and how likely it is (including every observation so far).
Fields
slots: Vec<Value>constraints: Constraintsinherited: Arc<BTreeSet<u64>>Latents passed into this call: restrictions on these remain observable by its caller even after every local alias dies. Constant per frame.
weight: Weightrun: u32When sampling, the run this world is (docs/semantics.md, section 14).
Implementations