pub enum Family {
Normal {
mean: f64,
sd: f64,
},
Lognormal {
mu: f64,
sigma: f64,
},
Uniform {
lo: f64,
hi: f64,
},
Beta {
a: f64,
b: f64,
},
Gamma {
shape: f64,
scale: f64,
},
Exponential {
rate: f64,
},
Triangular {
lo: f64,
mode: f64,
hi: f64,
},
Pert {
lo: f64,
mode: f64,
hi: f64,
},
}Expand description
A continuous distribution.
Variants
Normal
Lognormal
Uniform
Beta
Gamma
Exponential
Triangular
Pert
A beta distribution stretched over lo..hi with its mode at mode.
Implementations
Sourceimpl Family
impl Family
pub fn normal(mean: f64, sd: f64) -> OpResult<Family>
pub fn lognormal(mu: f64, sigma: f64) -> OpResult<Family>
pub fn uniform(lo: f64, hi: f64) -> OpResult<Family>
pub fn beta(a: f64, b: f64) -> OpResult<Family>
pub fn gamma(shape: f64, scale: f64) -> OpResult<Family>
pub fn exponential(rate: f64) -> OpResult<Family>
pub fn triangular(lo: f64, mode: f64, hi: f64) -> OpResult<Family>
pub fn pert(lo: f64, mode: f64, hi: f64) -> OpResult<Family>
Sourcepub fn estimate(a: f64, b: f64) -> OpResult<Family>
pub fn estimate(a: f64, b: f64) -> OpResult<Family>
a to b: the lognormal whose 5% and 95% quantiles are a and b.
Sourcepub fn normal_range(lo: f64, hi: f64) -> OpResult<Family>
pub fn normal_range(lo: f64, hi: f64) -> OpResult<Family>
normal_range(lo, hi): the normal whose 5% and 95% quantiles are
lo and hi.
pub fn mean(&self) -> f64
pub fn variance(&self) -> f64
pub fn sd(&self) -> f64
Sourcepub fn interval_moments(&self, lo: f64, hi: f64) -> (f64, f64)
pub fn interval_moments(&self, lo: f64, hi: f64) -> (f64, f64)
Conditional moments on a nonempty interval, using incomplete moments. Uniform and normal use centered formulas to avoid subtracting large location parameters when computing the variance.
pub fn pdf(&self, x: f64) -> f64
Sourcepub fn quantile(&self, p: f64) -> f64
pub fn quantile(&self, p: f64) -> f64
The value below which a share p of the distribution lies.
pub fn name(&self) -> &'static str