pub struct Budget {
pub max_integer_bits: u64,
pub integer_bytes_left: Arc<AtomicU64>,
pub max_string_bytes: usize,
pub string_bytes_left: Arc<AtomicU64>,
pub cancel: Option<Arc<AtomicBool>>,
pub max_outcomes: usize,
pub max_collection: usize,
pub work_left: u64,
pub shared: Option<Arc<AtomicU64>>,
}Expand description
Limits on building distributions, shared by everything in a run.
Fields
max_integer_bits: u64Maximum bits in the magnitude of a single integer.
integer_bytes_left: Arc<AtomicU64>Cumulative allowance for produced large integer payloads, shared by runs.
max_string_bytes: usizestring_bytes_left: Arc<AtomicU64>Cumulative string payload allowance, shared by sampled workers.
cancel: Option<Arc<AtomicBool>>max_outcomes: usizeThe most outcomes one distribution (or combination) may have.
max_collection: usizeThe most elements a collection built by the program may have.
work_left: u64Units of work left: world-steps plus outcomes computed.
Work shared with other threads, which work_left is topped up from
(when batches of runs are sampled in parallel).
Implementations
Sourceimpl Budget
impl Budget
pub fn unlimited() -> Budget
pub fn integer_bits(&self, bits: u64) -> OpResult<()>
pub fn string_size(&self, bytes: usize) -> OpResult<()>
Sourcepub fn string_work(&mut self, s: &str) -> OpResult<()>
pub fn string_work(&mut self, s: &str) -> OpResult<()>
Charge a scan before doing it, in units of 64 UTF-8 bytes.
Sourcepub fn string_allocation(&self, bytes: usize) -> OpResult<()>
pub fn string_allocation(&self, bytes: usize) -> OpResult<()>
Reserve payload bytes before allocation or growing a text builder.
Sourcepub fn integer_allocation(&self, bits: u64, count: u64) -> OpResult<()>
pub fn integer_allocation(&self, bits: u64, count: u64) -> OpResult<()>
Reserve before materializing a collection, or after a single bounded result. Conservative: shared results may be charged again; no refunds.
Sourcepub fn integer_work(
&mut self,
a: &Integer,
b: &Integer,
quadratic: bool,
) -> OpResult<()>
pub fn integer_work( &mut self, a: &Integer, b: &Integer, quadratic: bool, ) -> OpResult<()>
Charge before arithmetic, including copying and processing large operands.
Sourcepub fn outcomes(&self, n: u128) -> OpResult<()>
pub fn outcomes(&self, n: u128) -> OpResult<()>
Check that a distribution with n outcomes may be built.
Sourcepub fn collection(&self, n: u128) -> OpResult<()>
pub fn collection(&self, n: u128) -> OpResult<()>
Check that a collection with n elements may be built.