Module failure
probl_
engine
0.2.1
Module failure
Module Items
Structs
In crate probl_
engine
probl_engine
Module
failure
Worlds that ended at a fault, when the failure mode is partial (docs/semantics.md, section 11).
Structs

Failure
The worlds that failed at one place, with one kind of fault.
Failures
The worlds that failed, grouped by where and how.